from setuptools import setup

setup(name='hmd_dbt_pbt',
      version='1.2',
      description='Gaussian and Binomial distributions',
      packages=['hmd_dbt_pbt'],
      author='Ahmed Limem',
      author_email='ahmed.limem@etudiant-enit.utm.tn',
      zip_safe=False)
